@@ -8,12 +8,14 @@
 use std::borrow::Cow;
 
 use serde::{Deserialize, Serialize};
+#[cfg(feature = "validation")]
 use validator::Validate;
 
+#[cfg(feature = "validation")]
+use crate::val_helpr::ValidationResult;
 use crate::{compose::{Confirm, ConversationFilter},
             elems::select::conversation::build,
-            text,
-            val_helpr::ValidationResult};
+            text};
 
 /// # Multi-Select Conversation List
 ///
@@ -21,16 +23,18 @@ use crate::{compose::{Confirm, ConversationFilter},
 ///
 /// This select menu will populate its options with a list of public and private channels,
 /// DMs, and MPIMs visible to the current user in the active workspace.
-#[derive(Clone, Debug, Deserialize, Hash, PartialEq, Serialize, Validate)]
+#[derive(Clone, Debug, Deserialize, Hash, PartialEq, Serialize)]
+#[cfg_attr(feature = "validation", derive(Validate))]
 pub struct Conversation<'a> {
-  #[validate(custom = "crate::elems::select::validate::placeholder")]
+  #[cfg_attr(feature = "validation",
+             validate(custom = "crate::elems::select::validate::placeholder"))]
   pub(in crate::elems::select) placeholder: text::Text,
 
-  #[validate(length(max = 255))]
+  #[cfg_attr(feature = "validation", validate(length(max = 255)))]
   pub(in crate::elems::select) action_id: Cow<'a, str>,
 
   #[serde(skip_serializing_if = "Option::is_none")]
-  #[validate]
+  #[cfg_attr(feature = "validation", validate)]
   pub(in crate::elems::select) confirm: Option<Confirm>,
 
   #[serde(skip_serializing_if = "Option::is_none")]
@@ -39,11 +43,11 @@ pub struct Conversation<'a> {
   #[serde(skip_serializing_if = "Option::is_none")]
   pub(in crate::elems::select) default_to_current_conversation: Option<bool>,
 
-  #[validate]
+  #[cfg_attr(feature = "validation", validate)]
   #[serde(skip_serializing_if = "Option::is_none")]
   pub(in crate::elems::select) filter: Option<ConversationFilter>,
 
-  #[validate(range(min = 1))]
+  #[cfg_attr(feature = "validation", validate(range(min = 1)))]
   #[serde(skip_serializing_if = "Option::is_none")]
   pub(in crate::elems::select) max_selected_items: Option<u32>,
 }
@@ -62,11 +66,9 @@ impl<'a> Conversation<'a> {
   /// Validate that this conversation select agrees with Slack's model requirements
   ///
   /// # Errors
-  /// - If `from_placeholder_and_action_id` was called with
-  ///     `placeholder` longer than 150 chars
-  /// - If `from_placeholder_and_action_id` was called with
-  ///     `action_id` longer than 255 chars
-  /// - If `with_confirm` was called with an invalid `Confirm` structure
+  /// - If `placeholder` longer than 150 chars
+  /// - If `action_id` longer than 255 chars
+  /// - If `confirm` is an invalid `Confirm` structure
   ///
   /// # Example
   /// ```
@@ -85,6 +87,8 @@ impl<'a> Conversation<'a> {
   ///
   /// assert!(matches!(select.validate(), Err(_)))
   /// ```
+  #[cfg(feature = "validation")]
+  #[cfg_attr(docsrs, doc(cfg(feature = "validation")))]
   pub fn validate(&self) -> ValidationResult {
     Validate::validate(&self)
   }
